@@ -6,10 +6,10 @@ The pngme.api package exposes utilities to interact with Pngme's financial data.
 from .client import AsyncClient, Client
 from .core import AccessTokenExpired, AccessTokenInvalid
 from .resources.alerts import Alert
-from .resources.balances import BalanceRecord
+from .resources.balances import Balance
 from .resources.credit_report import CreditReport
 from .resources.institutions import Institution
-from .resources.transactions import TransactionRecord
+from .resources.transactions import Transaction
 from .resources.users import User
 
 __all__ = (
@@ -18,9 +18,9 @@ __all__ = (
     "AccessTokenExpired",
     "AccessTokenInvalid",
     "Alert",
-    "BalanceRecord",
+    "Balance",
     "CreditReport",
     "Institution",
-    "TransactionRecord",
+    "Transaction",
     "User",
 )
