@@ -1,21 +1,25 @@
 import asyncio
 from abc import ABC
 from datetime import datetime
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, TypedDict
 
 from pydantic import validate_arguments
 
 from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
-from .errors import ServerError
-from .retry import retry_policy
+from ..errors import ServerError
+from ..retry import retry_policy
 
 PATH = "/users"
 
 User = Dict[str, Any]
-UsersMeta = Dict[str, Any]
-UsersResponse = Dict[str, Any]
+
+
+class UsersResponse(TypedDict):
+    page: int
+    num_pages: int
+    users: List[User]
 
 
 class BaseUsersResource(ABC):
@@ -49,7 +53,9 @@ class BaseUsersResource(ABC):
             raise ServerError(response.text)
 
         assert response.status_code == 200, response.text
-        return response.json()  # type: ignore
+
+        users_response: UsersResponse = response.json()
+        return users_response
 
     @validate_arguments
     @cache
@@ -64,7 +70,7 @@ class BaseUsersResource(ABC):
             created_before=created_before,
             search=search,
         )
-        max_pages = response["_meta"]["max_pages"]
+        max_pages = response["num_pages"]
         if max_pages > 1:
             coroutines = [
                 self._get_page(
